@@ -67,6 +67,9 @@ int Help()
     TEXTOUT("      Create a policy (XSL) from a file");
     TEXTOUT("  --PolicyReferenceFile=VideoFile, -prf VideoFile");
     TEXTOUT("      Use the VideoFile as reference to compare in policy");
+    TEXTOUT("  --policyVerbosity=V, -pv V");
+    TEXTOUT("      Select verbosity (V) of the policy check, default 0");
+    TEXTOUT("      >= 1, show actual value also for passing rules");
     TEXTOUT("");
 
     TEXTOUT("Output Formats:");
@@ -88,6 +91,25 @@ int Help()
     TEXTOUT("      Apply the display transformation (XSL)");
     TEXTOUT("");
 
+    TEXTOUT("Output File:");
+    TEXTOUT("  --Output=file, -o file");
+    TEXTOUT("      Output MediaConch reports in file, trying to autodetect");
+    TEXTOUT("      the format from the extension or using the given display");
+    TEXTOUT("  Output-Text=file, -ot file");
+    TEXTOUT("      Output MediaConch reports in file in Text format");
+    TEXTOUT("  Output-Xml=file, -ox file");
+    TEXTOUT("      Output MediaConch reports in file in XML format");
+    TEXTOUT("  Output-Html=file, -oh file");
+    TEXTOUT("      Output MediaConch reports in file in HTML format");
+    TEXTOUT("  Output-Simple=file, -os file");
+    TEXTOUT("      Output MediaConch reports in file in a shorten form");
+    TEXTOUT("      (>1 line only if there are errors), default format");
+    TEXTOUT("  Output-Csv=file, -oc file");
+    TEXTOUT("      Output MediaConch reports in file in CSV format (only for policies)");
+    TEXTOUT("  Output-MaXml=file, -oa file");
+    TEXTOUT("      Output MediaConch reports in file in  MediaArea XML format");
+    TEXTOUT("");
+
     TEXTOUT("  --List");
     TEXTOUT("      List files analyzed.");
     TEXTOUT("");
@@ -160,6 +182,8 @@ int Help_Advanced()
     TEXTOUT("");
     TEXTOUT("--Force");
     TEXTOUT("    Force to parse the file if registered in database");
+    TEXTOUT("--Full");
+    TEXTOUT("    Full MediaInfo report (needed by some policies)");
     TEXTOUT("--NoMilAnalyze, -nmil");
     TEXTOUT("    Do not analyze with MediaInfoLib");
     TEXTOUT("--Async=yes, -as");
@@ -273,7 +297,7 @@ int Help_Xslt()
 //---------------------------------------------------------------------------
 int Version()
 {
-    TEXTOUT("MediaConch Command Line Interface 18.03.2");
+    TEXTOUT("MediaConch Command Line Interface 22.03");
 
     return CLI_RETURN_FINISH;
 }
