@@ -369,6 +369,7 @@ int DaemonClient::checker_file_information(int user, long id, MediaConchLib::Che
         info.generated_log = res->generated_log;
         info.generated_error_log = res->generated_error_log;
         info.analyzed = res->analyzed;
+        info.existing = res->existing;
         info.has_error = res->has_error;
         info.error_log = res->error_log;
         for (size_t i = 0; i < res->options.size(); ++i)
@@ -525,6 +526,8 @@ int DaemonClient::checker_status(int user, long file_id, MediaConchLib::Checker_
             *st_res.tool = (int)MediaConchLib::report_MediaVeraPdf;
         else if (*ok->tool == RESTAPI::DPFMANAGER)
             *st_res.tool = (int)MediaConchLib::report_MediaDpfManager;
+        else if (*ok->tool == RESTAPI::IMSC1VALIDATION)
+            *st_res.tool = (int)MediaConchLib::report_MediaImsc1Validation;
         else
             *st_res.tool = (int)MediaConchLib::report_MediaConch;
     }
@@ -642,6 +645,9 @@ int DaemonClient::checker_get_report(CheckerReport& cr, MediaConchLib::Checker_R
         req.reports.push_back(RESTAPI::VERAPDF);
     if (cr.report_set[MediaConchLib::report_MediaDpfManager])
         req.reports.push_back(RESTAPI::DPFMANAGER);
+    if (cr.report_set[MediaConchLib::report_MediaImsc1Validation])
+        req.reports.push_back(RESTAPI::IMSC1VALIDATION);
+
 
     // POLICY
     if (cr.policies_ids.size())
@@ -741,6 +747,8 @@ int DaemonClient::checker_validate(int user, MediaConchLib::report report,
         req.report = RESTAPI::VERAPDF;
     else if (report == MediaConchLib::report_MediaDpfManager)
         req.report = RESTAPI::DPFMANAGER;
+    else if (report == MediaConchLib::report_MediaImsc1Validation)
+        req.report = RESTAPI::IMSC1VALIDATION;
     else if (policies_ids.size())
     {
         // POLICY
@@ -956,7 +964,7 @@ int DaemonClient::policy_dump(int user, int id, bool must_be_public, std::string
 
 //---------------------------------------------------------------------------
 int DaemonClient::policy_change_info(int user, int id, const std::string& name, const std::string& description,
-                                     const std::string& license, std::string& err)
+                                     const std::vector<std::string>& tags, const std::string& license, std::string& err)
 {
     RESTAPI::Policy_Change_Info_Req  req;
     RESTAPI::Policy_Change_Info_Res *res = NULL;
@@ -964,6 +972,7 @@ int DaemonClient::policy_change_info(int user, int id, const std::string& name,
     req.id = id;
     req.name = name;
     req.description = description;
+    req.tags = tags;
     req.user = user;
     req.license = license;
 
