@@ -155,6 +155,12 @@ int MediaConchLib::mil_get_output_list(std::string& output_list, std::string& er
     return core->checker_list_mediainfo_outputs(output_list, error);
 }
 
+//---------------------------------------------------------------------------
+unsigned long long MediaConchLib::mil_version()
+{
+    return core->mil_version();
+}
+
 //---------------------------------------------------------------------------
 bool MediaConchLib::ReportAndFormatCombination_IsValid(const std::vector<std::string>&,
                                                        const std::bitset<MediaConchLib::report_Max>& reports,
@@ -405,7 +411,7 @@ int MediaConchLib::checker_validate(int user, report report, const std::vector<l
         return errorHttp_INVALID_DATA;
 
     if (report != report_MediaConch && !policies_ids.size() && !policies_contents.size() &&
-        report != report_MediaVeraPdf && report != report_MediaDpfManager)
+        report != report_MediaVeraPdf && report != report_MediaDpfManager && report != report_MediaImsc1Validation)
         return errorHttp_INVALID_DATA;
 
     if (use_daemon)
@@ -504,11 +510,11 @@ int MediaConchLib::policy_save(int user, int pos, std::string& err)
 
 //---------------------------------------------------------------------------
 int MediaConchLib::policy_change_info(int user, int id, const std::string& name, const std::string& description,
-                                      const std::string& license, std::string& err)
+                                      const std::vector<std::string>& tags, const std::string& license, std::string& err)
 {
     if (use_daemon)
-        return daemon_client->policy_change_info(user, id, name, description, license, err);
-    return core->policies.policy_change_info(user, id, name, description, license, err);
+        return daemon_client->policy_change_info(user, id, name, description, tags, license, err);
+    return core->policies.policy_change_info(user, id, name, description, tags, license, err);
 }
 
 //---------------------------------------------------------------------------
@@ -701,7 +707,14 @@ std::string MediaConchLib::Policy_Policy::to_str() const
     out << "\",\"type\":\"" << type;
     out << "\",\"name\":\"" << name;
     out << "\",\"description\":\"" << description;
-    out << "\",\"license\":\"" << license;
+    out << "\",\"tags\":[";
+    for (size_t i = 0; i < tags.size(); ++i)
+    {
+        if (i)
+            out << ",";
+        out << "\"" << tags[i] << "\"";
+    }
+    out << "],\"license\":\"" << license;
     out << "\",\"children\":[";
     for (size_t i = 0; i < children.size(); ++i)
     {
