@@ -68,6 +68,7 @@ public:
         report_MediaVeraPdf,
         report_MediaDpfManager,
         report_MicroMediaTrace,
+        report_MediaImsc1Validation,
         report_Max,
     };
 
@@ -150,7 +151,7 @@ public:
 
     struct Checker_FileInfo
     {
-        Checker_FileInfo() : source_id(-1), generated_time((size_t)-1), analyzed(false), has_error(false) {}
+        Checker_FileInfo() : source_id(-1), generated_time((size_t)-1), analyzed(false), existing(false), has_error(false) {}
 
         std::string                                      filename;
         std::string                                      file_last_modification;
@@ -161,6 +162,7 @@ public:
         long                                             source_id;
         size_t                                           generated_time;
         bool                                             analyzed;
+        bool                                             existing;
         bool                                             has_error;
         std::string                                      error_log;
     };
@@ -185,7 +187,7 @@ public:
     struct Policy_Policy
     {
         Policy_Policy() : id(-1), parent_id(-1), is_system(false) {}
-        Policy_Policy(const Policy_Policy* p) : id(p->id), parent_id(p->parent_id), is_system(p->is_system), is_public(p->is_public), kind(p->kind), type(p->type), name(p->name), description(p->description), license(p->license), children(p->children) {}
+        Policy_Policy(const Policy_Policy* p) : id(p->id), parent_id(p->parent_id), is_system(p->is_system), is_public(p->is_public), kind(p->kind), type(p->type), name(p->name), description(p->description), tags(p->tags), license(p->license), children(p->children) {}
         int                                       id;
         int                                       parent_id;
         bool                                      is_system;
@@ -194,6 +196,7 @@ public:
         std::string                               type;
         std::string                               name;
         std::string                               description;
+        std::vector<std::string>                  tags;
         std::string                               license;
         std::vector<std::pair<int, XSLT_Child> >  children;
         std::string                               to_str() const;
@@ -280,6 +283,7 @@ public:
     // MediaInfo
     bool mil_has_curl_enabled();
     int mil_get_output_list(std::string& output_list, std::string& error);
+    unsigned long long mil_version();
 
     // MediaConch
     int  mediaconch_get_plugins(std::vector<std::string>& plugins, std::string& error);
@@ -333,7 +337,8 @@ public:
     //   Create policy
     int                          policy_duplicate(int user, int id, int dst_policy_id, int *dst_user, bool must_be_public, std::string& err);
     int                          policy_move(int user, int id, int dst_policy_id, std::string& err);
-    int                          policy_change_info(int user, int id, const std::string& name, const std::string& description, const std::string& license, std::string& err);
+    int                          policy_change_info(int user, int id, const std::string& name, const std::string& description,
+                                                    const std::vector<std::string>& tags, const std::string& license, std::string& err);
     int                          policy_change_type(int user, int id, const std::string& type, std::string& err);
     int                          policy_change_is_public(int user, int id, bool is_public, std::string& err);
     int                          xslt_policy_create(int user, std::string& err, const std::string& type="and", int parent_id=-1);
