@@ -53,6 +53,7 @@ public:
         MEDIATRACE,
         VERAPDF,
         DPFMANAGER,
+        IMSC1VALIDATION,
     };
 
     std::string get_Report_string(Report r)
@@ -69,6 +70,7 @@ public:
             ReportString(MEDIATRACE);
             ReportString(VERAPDF);
             ReportString(DPFMANAGER);
+            ReportString(IMSC1VALIDATION);
             default:
                 break;
         }
@@ -88,6 +90,7 @@ public:
         ReportString(MEDIATRACE);
         ReportString(VERAPDF);
         ReportString(DPFMANAGER);
+        ReportString(IMSC1VALIDATION);
 
 #undef ReportString
 
@@ -497,7 +500,7 @@ public:
     struct Checker_File_Information_Res
     {
         Checker_File_Information_Res() : source_id(-1), generated_time((size_t)-1),
-                                         analyzed(false), has_error(false), nok(NULL) {}
+                                         analyzed(false), existing(false), has_error(false), nok(NULL) {}
         ~Checker_File_Information_Res();
 
         std::string                                       filename;
@@ -510,6 +513,7 @@ public:
         long                                              source_id;
         size_t                                            generated_time;
         bool                                              analyzed;
+        bool                                              existing;
         bool                                              has_error;
         MediaConch_Nok                                   *nok;
         std::string                                       to_str() const;
@@ -691,12 +695,13 @@ public:
     {
         Policy_Change_Info_Req() : user(-1), id(-1) {}
 
-        std::string  name;
-        std::string  description;
-        std::string  license;
-        int          user;
-        int          id;
-        std::string  to_str() const;
+        std::string              name;
+        std::string              description;
+        std::vector<std::string> tags;
+        std::string              license;
+        int                      user;
+        int                      id;
+        std::string              to_str() const;
     };
 
     struct Policy_Change_Info_Res
