@@ -6,6 +6,7 @@
 
 //---------------------------------------------------------------------------
 #include <sstream>
+#include <algorithm>
 #include <ZenLib/Dir.h>
 #include <ZenLib/File.h>
 #include <ZenLib/Ztring.h>
@@ -32,6 +33,8 @@
 #include "Common/generated/MediaTraceDisplayHtmlXsl.h"
 #include "Common/generated/MicroMediaTraceToMediaTraceXsl.h"
 
+#include "Checker/Checker.h"
+
 //---------------------------------------------------------------------------
 namespace MediaConch {
 
@@ -73,8 +76,8 @@ int Reports::checker_get_report(CheckerReport& cr, MediaConchLib::Checker_Report
     else
     {
         // For VeraPDF and DPFManager, to get the original XML
-        if ((cr.report_set[MediaConchLib::report_MediaVeraPdf] || cr.report_set[MediaConchLib::report_MediaDpfManager]) &&
-            cr.format == MediaConchLib::format_Xml &&
+        if ((cr.report_set[MediaConchLib::report_MediaVeraPdf] || cr.report_set[MediaConchLib::report_MediaDpfManager] ||
+             cr.report_set[MediaConchLib::report_MediaImsc1Validation]) && cr.format == MediaConchLib::format_Xml &&
             (!cr.display_content || !cr.display_content->size()) &&
             (!cr.display_name || !cr.display_name->size()))
             cr.format = MediaConchLib::format_OrigXml;
@@ -125,7 +128,8 @@ int Reports::checker_validate(int user, MediaConchLib::report report, const std:
                               std::vector<MediaConchLib::Checker_ValidateRes*>& result, std::string& err)
 {
     if (report != MediaConchLib::report_MediaConch && !policies_ids.size() && !policies_contents.size() &&
-        report != MediaConchLib::report_MediaVeraPdf && report != MediaConchLib::report_MediaDpfManager)
+        report != MediaConchLib::report_MediaVeraPdf && report != MediaConchLib::report_MediaDpfManager &&
+        report != MediaConchLib::report_MediaImsc1Validation)
         return -1;
 
     std::vector<long> file_tmp;
@@ -164,6 +168,12 @@ int Reports::checker_validate(int user, MediaConchLib::report report, const std:
             if (get_dpfmanager_report(user, files[i], report, res->valid, err) < 0)
                 return -1;
         }
+        else if (report == MediaConchLib::report_MediaImsc1Validation)
+        {
+            std::string report;
+            if (get_imsc1validation_report(user, files[i], report, res->valid, err) < 0)
+                return -1;
+        }
 
         result.push_back(res);
         if (!res->valid)
@@ -370,6 +380,42 @@ int Reports::get_reports_output(int user, const std::vector<long>& files,
                 result->report += "\r\n";
             }
         }
+
+        if (report_set[MediaConchLib::report_MediaImsc1Validation])
+        {
+            for (size_t i = 0; i < files.size(); ++i)
+            {
+                std::string report;
+                bool valid = false;
+                if (get_imsc1validation_report(user, files[i], report, valid, err) < 0)
+                    return -1;
+
+                if (!policy_is_valid(report))
+                    result->valid = false;
+                else
+                    result->valid = true;
+
+                if (f == MediaConchLib::format_OrigXml || f == MediaConchLib::format_Xml)
+                {
+                    // No transformation, keep the original XML
+                    result->report += report;
+                }
+                else
+                {
+                    if (f == MediaConchLib::format_Html)
+                        transform_with_xslt_html_memory(report, report);
+                    if (f == MediaConchLib::format_Simple)
+                        transform_with_xslt_simple_memory(report, report);
+                    else if (f == MediaConchLib::format_CSV)
+                        transform_with_xslt_csv_memory(report, report);
+                    else
+                        transform_with_xslt_text_memory(report, report);
+
+                    result->report += report;
+                }
+                result->report += "\r\n";
+            }
+        }
     }
 
     return 0;
@@ -438,6 +484,10 @@ int Reports::get_implementation_reports(int user, const std::vector<long>& files
         std::string file;
         if (core->checker_file_from_id(user, files[i], file, err) < 0)
             return -1;
+
+        if (is_attachment(file))
+            continue;
+
         xml_escape_attributes(file);
 
         report += "  <media ref=\"" + file + "\">";
@@ -526,6 +576,20 @@ int Reports::get_dpfmanager_report(int user, long file, std::string& report, boo
     return 0;
 }
 
+//---------------------------------------------------------------------------
+int Reports::get_imsc1validation_report(int user, long file, std::string& report, bool& valid, std::string& err)
+{
+    std::vector<long> files;
+    files.push_back(file);
+
+    if (core->get_report_saved(user, files, MediaConchLib::report_MediaImsc1Validation, MediaConchLib::format_Xml,
+                               "", report, err) < 0)
+        return -1;
+
+    valid = imsc1validation_report_is_valid(report);
+    return 0;
+}
+
 //***************************************************************************
 // Reports create/change
 //***************************************************************************
@@ -721,7 +785,7 @@ int Reports::create_report_ma_xml(int user, const std::vector<long>& files,
         if (core->checker_file_from_id(user, files[i], file, err) < 0)
             return -1;
 
-        if (file.rfind("attachment:", 0) == 0)
+        if (is_attachment(file))
             continue;
 
         xml_escape_attributes(file);
@@ -733,9 +797,20 @@ int Reports::create_report_ma_xml(int user, const std::vector<long>& files,
             if (core->get_report_saved(user, vec, MediaConchLib::report_MediaInfo, MediaConchLib::format_Xml, "", info, err) < 0)
                 return -1;
 
-            get_content_of_media_in_xml(info);
             if (info.length())
+            {
+                 std::map<std::string,std::string>::const_iterator it = options.find("full_report");
+                if (it != options.end() && it->second == "\"1\"")
+                {
+                    std::vector<std::pair<std::string,std::string> > mi_options;
+                    mi_options.push_back(std::make_pair(std::string("Complete"), std::string("1")));
+                    mi_options.push_back(std::make_pair(std::string("Language"), std::string("raw")));
+                    if(core->transform_mixml_report(info, "MIXML", mi_options, info, err) < 0)
+                        return -1;
+                }
+                get_content_of_media_in_xml(info);
                 report += "<MediaInfo xmlns=\"http" + (AcceptsHttps ? "s" : std::string()) + "://mediaarea.net/mediainfo\" version=\"2.0beta1\">" + info + "</MediaInfo>\n";
+            }
         }
 
         if (reports[MediaConchLib::report_MediaTrace])
@@ -847,6 +922,31 @@ void Reports::xml_escape_attributes(std::string& xml)
     }
 }
 
+//---------------------------------------------------------------------------
+bool  Reports::is_attachment(const std::string& file)
+{
+    if (file.length() > 10 && file.rfind("attachment", 0) == 0)
+    {
+        bool attachment=false;
+        for (size_t pos = 10; pos < file.length(); pos++)
+        {
+            if (file[pos] == ':')
+            {
+                attachment = true;
+                break;
+            }
+            else if ('0' <= file[pos] && file[pos] <= '9')
+                continue;
+            else
+                break;
+        }
+
+        if (attachment)
+            return true;
+    }
+    return false;
+}
+
 //***************************************************************************
 // Reports validity
 //***************************************************************************
@@ -932,6 +1032,12 @@ bool Reports::dpfmanager_report_is_valid(const std::string& report)
     return true;
 }
 
+//---------------------------------------------------------------------------
+bool Reports::imsc1validation_report_is_valid(const std::string& report)
+{
+    return implementation_is_valid(report);
+}
+
 //***************************************************************************
 // Policies
 //***************************************************************************
@@ -956,19 +1062,68 @@ int Reports::check_policies(int user, const std::vector<long>& files,
 
     unify_policy_options(user, options, err);
 
-    std::vector<std::string> policies;
-    if (core->policies.policy_get_policies(user, policies_ids, policies_contents, options, policies, err) < 0)
+    std::vector<std::string> xml_policies;
+    std::vector<std::string> xslt_policies;
+    if (core->policies.policy_get_policies(user, policies_ids, policies_contents, options, xml_policies, xslt_policies, err) < 0)
         return -1;
 
     std::stringstream Out;
     result->has_valid = true;
-    if (check_policies_xslts(user, files, options, policies, Out, result->valid, err) < 0)
-        return -1;
+    if (check_policies_xmls(user, files, options, xml_policies, Out, result->valid, err) < 0)
+    {
+        if (check_policies_xslts(user, files, options, xslt_policies, Out, result->valid, err) < 0)
+            return -1;
+    }
 
     result->report = Out.str();
     return 0;
 }
 
+//---------------------------------------------------------------------------
+int Reports::check_policies_xmls(int user, const std::vector<long>& files,
+                                   const std::map<std::string, std::string>& options,
+                                   const std::vector<std::string>& policies,
+                                   std::stringstream& Out, bool& valid, std::string& err)
+{
+    std::map<std::string,std::string> opts=options;
+    valid = true;
+
+    bool verbose = false;
+    if (opts.find("policy_verbosity") != opts.end() && opts["policy_verbosity"].length() && opts["policy_verbosity"] != "\"0\"")
+        verbose = true;
+
+    PolicyChecker checker;
+    for (size_t i = 0; i < policies.size(); ++i)
+        checker.add_policy(policies[i]);
+
+    if (checker.full_parse())
+        opts["full_report"] = "\"1\"";
+    else
+        return -1;
+
+    std::string report;
+    if (create_report_ma_xml(user, files, opts, report, get_bitset_with_mi_mmt(), err) < 0)
+    {
+        valid = false;
+        return 0;
+    }
+
+    std::string tmp;
+    if (checker.analyze(report, verbose, tmp) < 0)
+    {
+        valid = false;
+        Out << tmp;
+    }
+    else
+    {
+        Out << tmp;
+        if (!policy_is_valid(tmp))
+            valid = false;
+    }
+
+    return 0;
+}
+
 //---------------------------------------------------------------------------
 int Reports::check_policies_xslts(int user, const std::vector<long>& files,
                                    const std::map<std::string, std::string>& options,
@@ -1113,6 +1268,8 @@ int Reports::validate_xslt_from_memory(int user, const std::vector<long>& files,
         unify_implementation_options(options);
         S->set_options(options);
     }
+    else
+        S->set_options(opts);
 
     int ret = 0;
     if (S->register_schema_from_memory(memory))
@@ -1248,6 +1405,34 @@ void Reports::unify_policy_options(int user, std::map<std::string, std::string>&
 
         opts["compare"] = "\"" + path + "\"";
     }
+
+    if (opts.find("verbosity") != opts.end() && opts["verbosity"].length() && opts["verbosity"] != "-1")
+    {
+        std::string& verbosity = opts["verbosity"];
+        if (verbosity[0] == '"')
+            verbosity = std::string("'") + verbosity + std::string("'");
+        else
+            verbosity = std::string("\"") + verbosity + std::string("\"");
+    }
+    else
+        opts["verbosity"] = "\"5\"";
+
+    if (opts.find("policy_verbosity") != opts.end() && opts["policy_verbosity"].length() && opts["policy_verbosity"] != "-1")
+    {
+        std::string& verbosity = opts["policy_verbosity"];
+        if (verbosity[0] == '"')
+            verbosity = std::string("'") + verbosity + std::string("'");
+        else
+            verbosity = std::string("\"") + verbosity + std::string("\"");
+    }
+    else
+        opts["policy_verbosity"] = "\"0\"";
+
+    if (opts.find("full_report") != opts.end() && opts["full_report"].length() && opts["full_report"] != "-1" &&  opts["full_report"] != "0")
+        opts["full_report"] = "\"1\"";
+    else
+        opts["full_report"] = "\"0\"";
+
 }
 
 }
