@@ -311,6 +311,17 @@ int XsltPolicy::find_policy_node(xmlNodePtr node, bool is_root, XsltPolicy* curr
         }
         return 0;
     }
+    else if (name == "tag")
+    {
+        // Get tag
+        xmlChar *value = xmlNodeGetContent(node);
+        if (value)
+        {
+            current->tags.push_back(std::string((const char*)value));
+            xmlFree(value);
+        }
+        return 0;
+    }
 
 
     error = "The XML policy tag accepted are 'policy' or 'rule'";
@@ -511,6 +522,27 @@ int XsltPolicy::create_node_policy_child(xmlNodePtr& node, XsltPolicy *current)
         }
     }
 
+    //tags
+    if (current->tags.size())
+    {
+        for (size_t i = 0; i < current->tags.size(); ++i)
+        {
+            xmlNodePtr new_node = xmlNewNode(NULL, (const xmlChar*)"tag");
+            if (!new_node)
+            {
+                error = "Cannot create the policy children";
+                return -1;
+            }
+
+            xmlNodeSetContent(new_node, (const xmlChar*)current->tags[i].c_str());
+            if (!xmlAddChild(node, new_node))
+            {
+                error = "Cannot add child to policy children";
+                return -1;
+            }
+        }
+    }
+
     //isPublic
     if (current->keep_public && current->is_public)
         xmlNewProp(node, (const xmlChar *)"isPublic", (const xmlChar *)"true");
@@ -652,8 +684,10 @@ xmlDocPtr XsltPolicy::create_doc()
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-int XsltPolicy::create_rule_from_media_track_child(xmlNodePtr node, const std::string& type)
+int XsltPolicy::create_rule_from_media_track_child(xmlNodePtr node, const std::string& type, const std::string& prefix)
 {
+    std::string current;
+    size_t index = 0;
     for (xmlNodePtr child = node->children; child; child = child->next)
     {
         if (child->type != XML_ELEMENT_NODE || !child->name)
@@ -668,14 +702,29 @@ int XsltPolicy::create_rule_from_media_track_child(xmlNodePtr node, const std::s
          || name == "StreamSize"
          || name == "BitRate"
          || name == "Delay"
-         || name == "extra")
+         || name == "Count"
+         || name == "CodecID_Url")
             continue;
 
+        if(xmlChildElementCount(child))
+        {
+            if (current != name)
+            {
+                index = 0;
+                current = name;
+            }
+
+            std::stringstream ss;
+            ss << "[" << ++index << "]/";
+            create_rule_from_media_track_child(child, type,  prefix + name + ss.str());
+            continue;
+        }
+
         XsltPolicyRule *rule = new XsltPolicyRule;
 
         rule->id = rule->rule_id++;
         rule->track_type = type;
-        rule->field = (const char*)child->name;
+        rule->field = prefix + (const char*)child->name;
         rule->ope = "=";
         rule->occurrence = -1;
         xmlChar *content = xmlNodeGetContent(child);
