@@ -41,7 +41,7 @@ namespace MediaConch
     //**************************************************************************
     // Daemon
     //**************************************************************************
-    std::string Daemon::version = "18.03.2.0";
+    std::string Daemon::version = "22.03.0";
 
     //--------------------------------------------------------------------------
     Daemon::Daemon() : is_daemon(true), httpd(NULL), logger(NULL), watch_folder_user(NULL),
@@ -866,6 +866,11 @@ namespace MediaConch
                     ok->tool = new RESTAPI::Report;
                     *ok->tool = RESTAPI::DPFMANAGER;
                 }
+                else if (*st_res.tool == (int)MediaConchLib::report_MediaImsc1Validation)
+                {
+                    ok->tool = new RESTAPI::Report;
+                    *ok->tool = RESTAPI::IMSC1VALIDATION;
+                }
             }
 
             if (st_res.percent)
@@ -928,6 +933,8 @@ namespace MediaConch
                 cr.report_set.set(MediaConchLib::report_MediaVeraPdf);
             if (req->reports[j] == RESTAPI::DPFMANAGER)
                 cr.report_set.set(MediaConchLib::report_MediaDpfManager);
+            if (req->reports[j] == RESTAPI::IMSC1VALIDATION)
+                cr.report_set.set(MediaConchLib::report_MediaImsc1Validation);
         }
 
         if (!cr.report_set.count() && !req->policies_ids.size() && !req->policies_contents.size())
@@ -1072,6 +1079,8 @@ namespace MediaConch
             report = MediaConchLib::report_MediaVeraPdf;
         else if (req->report == RESTAPI::DPFMANAGER)
             report = MediaConchLib::report_MediaDpfManager;
+        else if (req->report == RESTAPI::IMSC1VALIDATION)
+            report = MediaConchLib::report_MediaImsc1Validation;
         else if (req->report != RESTAPI::POLICY)
             return -1;
         else
@@ -1173,6 +1182,7 @@ namespace MediaConch
             res.filename = info.filename;
             res.file_last_modification = info.file_last_modification;
             res.analyzed = info.analyzed;
+            res.existing = info.existing;
             for (size_t j = 0; j < info.generated_id.size(); ++j)
                 res.generated_id.push_back(info.generated_id[j]);
             res.source_id = info.source_id;
@@ -1315,7 +1325,7 @@ namespace MediaConch
         FUN_CMD_START(Policy_Change_Info)
 
         std::string err;
-        if (d->MCL->policy_change_info(req->user, req->id, req->name, req->description, req->license, err) < 0)
+        if (d->MCL->policy_change_info(req->user, req->id, req->name, req->description, req->tags, req->license, err) < 0)
             FUN_CMD_NOK(res, err, -1)
 
         FUN_CMD_END(Policy_Change_Info)
