@@ -208,6 +208,12 @@ bool MainWindow::mil_has_curl_enabled()
     return MCL.mil_has_curl_enabled();
 }
 
+//---------------------------------------------------------------------------
+unsigned long long MainWindow::mil_version()
+{
+    return MCL.mil_version();
+}
+
 //---------------------------------------------------------------------------
 bool MainWindow::close()
 {
@@ -1005,10 +1011,10 @@ int MainWindow::policy_move(int id, int dst_policy_id, QString& err)
 
 //---------------------------------------------------------------------------
 int MainWindow::policy_change_info(int id, const std::string& name, const std::string& description,
-                                   const std::string& license, QString& err)
+                                   const std::vector<std::string>& tags, const std::string& license, QString& err)
 {
     std::string error;
-    int ret = MCL.policy_change_info(user, id, name, description, license, error);
+    int ret = MCL.policy_change_info(user, id, name, description, tags, license, error);
     if (ret < 0)
         err = QString().fromUtf8(error.c_str(), error.size());
     return ret;
@@ -1507,6 +1513,16 @@ int MainWindow::checker_file_from_id(long id, std::string& file, std::string& er
     return MCL.checker_file_from_id(user, id, file, err);
 }
 
+//---------------------------------------------------------------------------
+long MainWindow::checker_id_from_filename(const std::string& filename, const std::vector<std::string>& options, std::string& err)
+{
+    std::vector<std::pair<std::string, std::string> > opts;
+    for (size_t i = 0; i + 1 < options.size(); i += 2)
+        opts.push_back(std::make_pair(options[i], options[i + 1]));
+
+    return MCL.checker_id_from_filename(user, filename, opts, err);
+}
+
 //---------------------------------------------------------------------------
 int MainWindow::checker_file_information(long id, MediaConchLib::Checker_FileInfo& file, std::string& err)
 {
